@@ -53,6 +53,7 @@ limits = [
 limits_by_id = {}
 
 limit_by_sasl = True
+limit_by_sender = False
 limit_by_ip = False
 
 limited_networks = []
@@ -68,7 +69,7 @@ db_error_action = "dunno"
 report = False
 # from who to send emails reports
 report_from = None
-# address to send emails reports to
+# address to send emails reports to. It can be a single email or a list of emails
 report_to = None
 # subject of the report email
 report_subject = "policyd-rate-limit report"
@@ -83,3 +84,6 @@ smtp_server = ("localhost", 25)
 smtp_starttls = False
 # Should we use credentials to connect to smtp_server ? if yes set ("user", "password"), else None
 smtp_credentials = None
+
+# The time in seconds before an unused socket gets closed
+delay_to_close = 300
